[![Build Status](https://travis-ci.org/PYNE-AD/cs207-FinalProject.svg?branch=master)](https://travis-ci.org/PYNE-AD/cs207-FinalProject)

[![Coverage Status](https://codecov.io/gh/PYNE-AD/cs207-FinalProject/branch/master/graph/badge.svg)](https://codecov.io/gh/PYNE-AD/cs207-FinalProject)

# cs207-FinalProject

## Group No. 12

- 
  Paulina Toro Isaza

- Yaowei Li

- Nikhil Vanderklaauw

- Emma Li

## Installation

### Requirements

1. Ensure you can run Python from the command line. 
   - You can check this by running: `python --version`
2. Ensure you can run  pip form the command line. 
   - You can check this by running: `pip --version`

### Install the package

1. Using virtual environment

   - Create an environment with the command: `conda create --name env_name python`
   - Activating the environment: `conda activate env_name`
   - You can get out of the environment (deactivate it) by typing: `conda deactivate`

2. Install the package from PyPi and dependencies

   - Type  `pip install ADPYNE-207`

